@@ -2,7 +2,6 @@ def main(splash=True):
     import os
     import pkg_resources
     import sys
-    import time
 
     from PyQt5.QtWidgets import QApplication
 
@@ -12,14 +11,19 @@ def main(splash=True):
     if splash:
         from PyQt5.QtWidgets import QSplashScreen
         from PyQt5.QtGui import QPixmap
+        from PyQt5.QtCore import QEventLoop
         splash_path = os.path.join(imdir, "splash.png")
         splash_pix = QPixmap(splash_path)
         splash = QSplashScreen(splash_pix)
         splash.setMask(splash_pix.mask())
         splash.show()
-        # make sure Qt really displays the splash screen
-        time.sleep(.07)
-        app.processEvents()
+        app.processEvents(QEventLoop.AllEvents, 300)
+
+    import warnings
+    from requests.packages.urllib3.exceptions import SubjectAltNameWarning
+    # Ignore SubjectAltNameWarning for certificates in medical branding,
+    # because they will show up in the dclab-compress-warnings log.
+    warnings.filterwarnings("ignore", category=SubjectAltNameWarning)
 
     from PyQt5 import QtCore, QtGui
     from .gui import DCORAid
